@@ -16,7 +16,8 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with GNU Fortran; see the file COPYING.  If not, write to
-the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
+02111-1307, USA.
 
    Related Modules:
 
@@ -158,7 +159,7 @@ ffeglobal_init_common (ffesymbol s, ffelexToken t)
 	}
 
       /* Complain about just one attempt to reinit per program unit, but
-         continue referring back to the first such successful attempt.  */
+	 continue referring back to the first such successful attempt.  */
     }
   else
     {
