@@ -225,6 +225,8 @@ ffeintrin_check_ (ffeintrinImp imp, ffebldOp op,
       basic = *(argc++);
       kind = *(argc++);
       if ((*argc == '&')
+	  || (*argc == 'g')
+	  || (*argc == 's')
 	  || (*argc == 'w')
 	  || (*argc == 'x'))
 	extra = *(argc++);
@@ -376,6 +378,15 @@ ffeintrin_check_ (ffeintrinImp imp, ffebldOp op,
 		okay = FALSE;
 	      break;
 
+	    case 'g':
+	      if ((ffebld_op (a) != FFEBLD_opLABTER)
+		  && (ffebld_op (a) != FFEBLD_opLABTOK))
+		okay = FALSE;
+	      break;
+
+	    case 's':
+	      break;
+
 	    case 'w':
 	    case 'x':
 	      if ((ffeinfo_kind (i) != FFEINFO_kindENTITY)
@@ -695,6 +706,8 @@ ffeintrin_check_ (ffeintrinImp imp, ffebldOp op,
       basic = *(argc++);
       kind = *(argc++);
       if ((*argc == '&')
+	  || (*argc == 'g')
+	  || (*argc == 's')
 	  || (*argc == 'w')
 	  || (*argc == 'x'))
 	extra = *(argc++);
@@ -865,6 +878,15 @@ ffeintrin_check_ (ffeintrinImp imp, ffebldOp op,
 		okay = FALSE;
 	      break;
 
+	    case 'g':
+	      if ((ffebld_op (a) != FFEBLD_opLABTER)
+		  && (ffebld_op (a) != FFEBLD_opLABTOK))
+		okay = FALSE;
+	      break;
+
+	    case 's':
+	      break;
+
 	    case 'w':
 	    case 'x':
 	      if ((ffeinfo_kind (i) != FFEINFO_kindENTITY)
@@ -1452,7 +1474,8 @@ ffeintrin_init_0 ()
 	      break;
 	    }
 	  if ((c[3] == '&')
-	      || (c[3] == 'w')
+	      || (c[3] == 's')
+	  || (c[3] == 'w')
 	  || (c[3] == 'x'))
 	    ++c;
 	  if (c[3] == ',')
