@@ -30,8 +30,12 @@ the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
   "-fversion",
   "-fnull-version",
   "-fset-g77-defaults",
-  "-fident",
-  "-fno-ident",
+/*"-fident",*/
+/*"-fno-ident",*/
+  "-ff66",
+  "-fno-f66",
+  "-ff77",
+  "-fno-f77",
   "-ff90",
   "-fno-f90",
   "-fautomatic",
@@ -54,8 +58,14 @@ the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
   "-fno-ugly",
   "-fugly-args",
   "-fno-ugly-args",
+  "-fugly-assumed",
+  "-fno-ugly-assumed",
+  "-fugly-comma",
+  "-fno-ugly-comma",
   "-fugly-init",
   "-fno-ugly-init",
+  "-fugly-logint",
+  "-fno-ugly-logint",
   "-fdebug",
   "-fno-debug",
   "-finit-local-zero",
@@ -113,11 +123,19 @@ the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
   "-fvxt-intrinsics-enable",
   "-fzeros",
   "-fno-zeros",
-  "-Wimplicit",
-  "-Wno-implicit",
+  "-fdebug-kludge",
+  "-fno-debug-kludge",
+  "-fonetrip",
+  "-fno-onetrip",
+  "-fsilent",
+  "-fno-silent",
+  "-ftypeless-boz",
+  "-fno-typeless-boz",
+/*"-Wimplicit",*/
+/*"-Wno-implicit",*/
   "-Wsurprising",
   "-Wno-surprising",
-  "-Wall",
+/*"-Wall",*/
 /* Prefix options.  */
   "-I",
   "-ffixed-line-length-",
