@@ -16,7 +16,8 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with GNU Fortran; see the file COPYING.  If not, write to
-the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.	 */
+the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
+02111-1307, USA.	 */
 
 #include "proj.h"
 #include <ctype.h>
