@@ -5,14 +5,17 @@
 
 #include "f2c.h"
 #ifndef NO_OVERWRITE
+#include <stdio.h>
 #undef abs
 #ifdef KR_headers
- extern char *malloc();
+ extern char *F77_aloc();
  extern void free();
+ extern void exit_();
 #else
-#include "stdlib.h"
+#include <stdlib.h>
+ extern char *F77_aloc(ftnlen, char*);
 #endif
-#include "string.h"
+#include <string.h>
 #endif /* NO_OVERWRITE */
 
  VOID
@@ -45,8 +48,10 @@ s_cat(char *lp, char *rpp[], ftnlen rnp[], ftnlen *np, ftnlen ll)
 			continue;
 			}
 		lp0 = lp;
-		lp = lp1 = malloc(L = ll);
+		lp = lp1 = F77_aloc(L = ll, "s_cat");
+		break;
 		}
+	lp1 = lp;
 #endif /* NO_OVERWRITE */
 	for(i = 0 ; i < n ; ++i) {
 		nc = ll;
