@@ -1,6 +1,6 @@
 #ifndef NON_UNIX_STDIO
-#include "sys/types.h"
-#include "sys/stat.h"
+#include <sys/types.h>
+#include <sys/stat.h>
 #endif
 #include "f2c.h"
 #include "fio.h"
@@ -13,7 +13,7 @@ extern char *malloc();
 #undef abs
 #undef min
 #undef max
-#include "stdlib.h"
+#include <stdlib.h>
 #endif
 #endif
 
