@@ -199,7 +199,8 @@ ffesta_add_possible_nonexec_ (ffelexHandler fn)
    if (!ffesta_inhibited_exec_transition_())  // couldn't transition...
 
    Invokes ffestc_exec_transition, but first enables ffebad and ffesta and
-   afterwards disables them again.  Then returns the result of the invoke.  */
+   afterwards disables them again.  Then returns the result of the
+   invocation of ffestc_exec_transition.  */
 
 static bool
 ffesta_inhibited_exec_transition_ ()
@@ -329,7 +330,7 @@ ffesta_save_ (ffelexToken t)
 	}
     }
 
-next_handler:			/* :::::::::::::::::::: */
+ next_handler:			/* :::::::::::::::::::: */
 
   /* Note that a shutdown also happens after seeing the first two tokens
      after "IF (expr)" or "WHERE (expr)" where a statement follows, even
@@ -409,13 +410,6 @@ next_handler:			/* :::::::::::::::::::: */
       else
 	{			/* Switching from [empty?] list of nonexecs
 				   to nonempty list of execs at this point. */
-	  if (!ffesta_seen_first_exec)
-	    {			/* Make sure ffestc_exec_transition()
-				   returned TRUE, fyi; it should be tested in
-				   the if statement that sends us here. */
-	      ffesta_seen_first_exec = TRUE;
-	      ffestd_exec_begin ();
-	    }
 	  ffesta_tokens[0] = ffelex_token_use (ffesta_token_0_);
 	  ffesymbol_set_retractable (ffesta_scratch_pool);
 	}
@@ -869,6 +863,18 @@ ffesta_second_ (ffelexToken t)
       ffesta_add_possible_nonexec_ ((ffelexHandler) ffestb_decl_gentype);
       break;
 
+    case FFESTR_firstBYTE:
+      ffestb_args.decl.len = FFESTR_firstlBYTE;
+      ffestb_args.decl.type = FFESTP_typeBYTE;
+      ffesta_add_possible_nonexec_ ((ffelexHandler) ffestb_decl_gentype);
+      break;
+
+    case FFESTR_firstWORD:
+      ffestb_args.decl.len = FFESTR_firstlWORD;
+      ffestb_args.decl.type = FFESTP_typeWORD;
+      ffesta_add_possible_nonexec_ ((ffelexHandler) ffestb_decl_gentype);
+      break;
+
 #if FFESTR_F90
     case FFESTR_firstINTENT:
       ffestb_args.varlist.len = FFESTR_firstlINTENT;
@@ -1140,19 +1146,10 @@ ffesta_second_ (ffelexToken t)
 	}
       else if (ffesta_seen_first_exec)
 	;			/* Have an exec stmt after exec transition. */
-      else if (ffestc_exec_transition ())
-	{			/* Have an exec stmt before the exec
-				   transition AND our statement state allows
-				   such a transition at this point, in which
-				   case f_e_t_ updates that state and returns
-				   TRUE. */
-	  ffesta_seen_first_exec = TRUE;
-	  ffestd_exec_begin ();
-	}
-      else			/* Can't do exec stmt yet. */
+      else if (!ffestc_exec_transition ())
+	/* 1 exec stmt only, but not valid in context, so pretend as though
+	   statement is unrecognized. */
 	goto no_stmts;		/* :::::::::::::::::::: */
-      /* 1 exec stmt only, but not valid in context, so pretend as though
-	 statement is unrecognized. */
       break;
 
     default:			/* More than one, so try them in order. */
@@ -1166,16 +1163,7 @@ ffesta_second_ (ffelexToken t)
 	  assert (ffesta_current_handler_ != NULL);
 	  if (!ffesta_seen_first_exec)
 	    {			/* Need to do exec transition now. */
-	      if (ffestc_exec_transition ())
-		{		/* Have an exec stmt before the exec
-				   transition AND our statement state allows
-				   such a transition at this point, in which
-				   case f_e_t_ updates that state and returns
-				   TRUE. */
-		  ffesta_seen_first_exec = TRUE;
-		  ffestd_exec_begin ();
-		}
-	      else
+	      if (!ffestc_exec_transition ())
 		goto no_stmts;	/* :::::::::::::::::::: */
 	    }
 	}
