@@ -84,6 +84,7 @@ extern bool ffe_is_automatic_;
 extern bool ffe_is_backslash_;
 extern bool ffe_is_underscoring_;
 extern bool ffe_is_second_underscore_;
+extern bool ffe_is_debug_kludge_;
 extern bool ffe_is_dollar_ok_;
 extern bool ffe_is_f2c_;
 extern bool ffe_is_f2c_library_;
@@ -92,11 +93,16 @@ extern bool ffe_is_free_form_;
 extern bool ffe_is_ident_;
 extern bool ffe_is_init_local_zero_;
 extern bool ffe_is_mainprog_;
+extern bool ffe_is_onetrip_;
+extern bool ffe_is_silent_;
+extern bool ffe_is_typeless_boz_;
 extern bool ffe_is_pedantic_;
 extern bool ffe_is_saveall_;
-extern bool ffe_is_ugly_;
 extern bool ffe_is_ugly_args_;
+extern bool ffe_is_ugly_assumed_;
+extern bool ffe_is_ugly_comma_;
 extern bool ffe_is_ugly_init_;
+extern bool ffe_is_ugly_logint_;
 extern bool ffe_is_version_;
 extern bool ffe_is_vxt_not_90_;
 extern bool ffe_is_warn_implicit_;
@@ -157,6 +163,7 @@ void ffe_terminate_4 (void);
 #define ffe_is_90() ffe_is_90_
 #define ffe_is_automatic() ffe_is_automatic_
 #define ffe_is_backslash() ffe_is_backslash_
+#define ffe_is_debug_kludge() ffe_is_debug_kludge_
 #define ffe_is_do_internal_checks() ffe_is_do_internal_checks_
 #define ffe_is_dollar_ok() ffe_is_dollar_ok_
 #define ffe_is_f2c() ffe_is_f2c_
@@ -166,13 +173,18 @@ void ffe_terminate_4 (void);
 #define ffe_is_ident() ffe_is_ident_
 #define ffe_is_init_local_zero() ffe_is_init_local_zero_
 #define ffe_is_mainprog() ffe_is_mainprog_
+#define ffe_is_onetrip() ffe_is_onetrip_
 #define ffe_is_pedantic() ffe_is_pedantic_
 #define ffe_is_pedantic_not_90() (ffe_is_pedantic_ && !ffe_is_90_)
 #define ffe_is_saveall() ffe_is_saveall_
 #define ffe_is_second_underscore() ffe_is_second_underscore_
-#define ffe_is_ugly() ffe_is_ugly_
+#define ffe_is_silent() ffe_is_silent_
+#define ffe_is_typeless_boz() ffe_is_typeless_boz_
 #define ffe_is_ugly_args() ffe_is_ugly_args_
+#define ffe_is_ugly_assumed() ffe_is_ugly_assumed_
+#define ffe_is_ugly_comma() ffe_is_ugly_comma_
 #define ffe_is_ugly_init() ffe_is_ugly_init_
+#define ffe_is_ugly_logint() ffe_is_ugly_logint_
 #define ffe_is_underscoring() ffe_is_underscoring_
 #define ffe_is_version() ffe_is_version_
 #define ffe_is_vxt_not_90() ffe_is_vxt_not_90_
@@ -196,6 +208,7 @@ void ffe_terminate_4 (void);
 #define ffe_set_is_90(f) (ffe_is_90_ = (f))
 #define ffe_set_is_automatic(f) (ffe_is_automatic_ = (f))
 #define ffe_set_is_backslash(f) (ffe_is_backslash_ = (f))
+#define ffe_set_is_debug_kludge(f) (ffe_is_debug_kludge_ = (f))
 #define ffe_set_is_do_internal_checks(f) (ffe_set_is_do_internal_checks_ = (f))
 #define ffe_set_is_dollar_ok(f) (ffe_is_dollar_ok_ = (f))
 #define ffe_set_is_f2c(f) (ffe_is_f2c_ = (f))
@@ -205,12 +218,17 @@ void ffe_terminate_4 (void);
 #define ffe_set_is_ident(f) (ffe_is_ident_ = (f))
 #define ffe_set_is_init_local_zero(f) (ffe_is_init_local_zero_ = (f))
 #define ffe_set_is_mainprog(f) (ffe_is_mainprog_ = (f))
+#define ffe_set_is_onetrip(f) (ffe_is_onetrip_ = (f))
 #define ffe_set_is_pedantic(f) (ffe_is_pedantic_ = (f))
 #define ffe_set_is_saveall(f) (ffe_is_saveall_ = (f))
 #define ffe_set_is_second_underscore(f) (ffe_is_second_underscore_ = (f))
-#define ffe_set_is_ugly(f) (ffe_is_ugly_ = (f))
+#define ffe_set_is_silent(f) (ffe_is_silent_ = (f))
+#define ffe_set_is_typeless_boz(f) (ffe_is_typeless_boz_ = (f))
 #define ffe_set_is_ugly_args(f) (ffe_is_ugly_args_ = (f))
+#define ffe_set_is_ugly_assumed(f) (ffe_is_ugly_assumed_ = (f))
+#define ffe_set_is_ugly_comma(f) (ffe_is_ugly_comma_ = (f))
 #define ffe_set_is_ugly_init(f) (ffe_is_ugly_init_ = (f))
+#define ffe_set_is_ugly_logint(f) (ffe_is_ugly_logint_ = (f))
 #define ffe_set_is_underscoring(f) (ffe_is_underscoring_ = (f))
 #define ffe_set_is_version(f) (ffe_is_version_ = (f))
 #define ffe_set_is_vxt_not_90(f) (ffe_is_vxt_not_90_ = (f))
